package com.ruoyi.buyerapi.mapper;

import java.util.List;
import com.ruoyi.buyerapi.domain.BuyerVoucherInfo;
import com.ruoyi.buyerapi.domain.BuyerVoucherInfoExport;

/**
 * 辅助帐凭证详细列Mapper接口
 *
 * @author ruoyi
 * @date 2022-09-22
 */
public interface BuyerVoucherInfoMapper
{
    /**
     * 查询辅助帐凭证详细列
     *
     * @param id 辅助帐凭证详细列主键
     * @return 辅助帐凭证详细列
     */
    public BuyerVoucherInfo selectBuyerVoucherInfoById(Long id);

    /**
     * 查询辅助帐凭证详细列列表
     *
     * @param buyerVoucherInfo 辅助帐凭证详细列
     * @return 辅助帐凭证详细列集合
     */
    public List<BuyerVoucherInfo> selectBuyerVoucherInfoList(BuyerVoucherInfo buyerVoucherInfo);

    public List<BuyerVoucherInfoExport> selectBuyerVoucherInfoListExport(String projectId);

    /**
     * 新增辅助帐凭证详细列
     *
     * @param buyerVoucherInfo 辅助帐凭证详细列
     * @return 结果
     */
    public int insertBuyerVoucherInfo(BuyerVoucherInfo buyerVoucherInfo);

    /**
     * 修改辅助帐凭证详细列
     *
     * @param buyerVoucherInfo 辅助帐凭证详细列
     * @return 结果
     */
    public int updateBuyerVoucherInfo(BuyerVoucherInfo buyerVoucherInfo);

    /**
     * 删除辅助帐凭证详细列
     *
     * @param id 辅助帐凭证详细列主键
     * @return 结果
     */
    public int deleteBuyerVoucherInfoById(Long id);

    /**
     * 删除辅助帐凭证详细列
     *
     * @param buyerVoucherInfo 辅助帐凭证详细
     * @return 结果
     */
    public int deleteBuyerVoucherInfo(BuyerVoucherInfo buyerVoucherInfo);

    /**
     * 批量删除辅助帐凭证详细列
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBuyerVoucherInfoByIds(Long[] ids);
}
